# nw-acceptance-designer

Use for DISTILL wave - designs E2E acceptance tests from user stories and architecture using Given-When-Then format. Creates executable specifications that drive Outside-In TDD development.

**Wave:** DISTILL
**Model:** inherit
**Max turns:** 30
**Tools:** Read, Write, Edit, Bash, Glob, Grep, Task

## Commands

- [`/nw:devops`](../commands/index.md)
- [`/nw:distill`](../commands/index.md)
- [`/nw:finalize`](../commands/index.md)

## Skills

- [bdd-methodology](../../../nWave/skills/acceptance-designer/bdd-methodology.md) — BDD patterns for acceptance test design - Given-When-Then structure, scenario writing rules, pytest-bdd implementation, anti-patterns, and living documentation
- [critique-dimensions](../../../nWave/skills/acceptance-designer/critique-dimensions.md) — Review dimensions for acceptance test quality - happy path bias, GWT compliance, business language purity, coverage completeness, walking skeleton user-centricity, and priority validation
- [critique-dimensions](../../../nWave/skills/agent-builder/critique-dimensions.md) — Review dimensions for validating agent quality - template compliance, safety, testing, and priority validation
- [critique-dimensions](../../../nWave/skills/agent-builder-reviewer/critique-dimensions.md) — Review dimensions for validating agent quality - template compliance, safety, testing, and priority validation
- [critique-dimensions](../../../nWave/skills/platform-architect-reviewer/critique-dimensions.md) — Platform design review critique dimensions and severity levels. Load when reviewing CI/CD pipelines, infrastructure, deployment strategies, observability, or security designs.
- [critique-dimensions](../../../nWave/skills/researcher-reviewer/critique-dimensions.md) — Critique dimensions and scoring for research document reviews
- [critique-dimensions](../../../nWave/skills/solution-architect/critique-dimensions.md) — Architecture quality critique dimensions for peer review. Load when invoking solution-architect-reviewer or performing self-review of architecture documents.
- [critique-dimensions](../../../nWave/skills/solution-architect-reviewer/critique-dimensions.md) — Architecture quality critique dimensions for peer review. Load when performing architecture document reviews.
- [test-design-mandates](../../../nWave/skills/acceptance-designer/test-design-mandates.md) — Three design mandates for acceptance tests - hexagonal boundary enforcement, business language abstraction, user journey completeness, and walking skeleton strategy
- [test-organization-conventions](../../../nWave/skills/acceptance-designer/test-organization-conventions.md) — Test directory structure patterns by architecture style, language conventions, naming rules, and fixture placement. Decision tree for selecting test organization strategy.
